#[derive(CloneToUninit)]
{
// Attributes available to this derive:
#[dst]
}
Derive macro for the CloneToUninit trait for DSTs.
If there are any generic types with a ?Sized trait bound, those are assumed to be
the type of the DST, so the CloneToUninit trait bound will be added. All other
generic types will have the Clone trait bound added.